# SwaggerClient-php
Nowcast weather data for latitude/longitude points, ZIP/Postal Codes, Designated Market Areas, and OnPoint™ points. The Weather Source Nowcast API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  An API key is required to authorize requests. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/).

This PHP package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Build package: io.swagger.codegen.v3.generators.php.PhpClientCodegen
For more information, please visit [https://developer.weathersourceapis.com/](https://developer.weathersourceapis.com/)

## Requirements

PHP 5.5 and later

## Installation & Usage
### Composer

To install the bindings via [Composer](http://getcomposer.org/), add the following to `composer.json`:

```
{
  "repositories": [
    {
      "type": "git",
      "url": "https://github.com/GIT_USER_ID/GIT_REPO_ID.git"
    }
  ],
  "require": {
    "GIT_USER_ID/GIT_REPO_ID": "*@dev"
  }
}
```

Then run `composer install`

### Manual Installation

Download the files and include `autoload.php`:

```php
    require_once('/path/to/SwaggerClient-php/vendor/autoload.php');
```

## Tests

To run the unit tests:

```
composer install
./vendor/bin/phpunit
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precipFlag, precipIntensity, snowfallFlag, snowfallIntensity)* * allPres *(mslPres, presTend, sfcPres)* * allRad *(radSolar)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(cldCvr, feelsLike, precipFlag, precipIntensity, relHum, snowfallFlag, snowfallIntensity, temp, windDir, windSpd)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdGet($dma_id, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

## Documentation for API Endpoints

All URIs are relative to *https://nowcast.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DmasApi* | [**dmasDmaIdGet**](docs/Api/DmasApi.md#dmasdmaidget) | **GET** /dmas/{dmaId} | A nowcast for a DMA.
*OnpointsApi* | [**onpointsOnpointIdGet**](docs/Api/OnpointsApi.md#onpointsonpointidget) | **GET** /onpoints/{onpointId} | A nowcast for an OnPoint™ point.
*PointsApi* | [**pointsLatitudelongitudeGet**](docs/Api/PointsApi.md#pointslatitudelongitudeget) | **GET** /points/{latitude},{longitude} | A nowcast for a Latitude/Longitude point.
*PostcodesApi* | [**postcodesPostcodecountryCodeGet**](docs/Api/PostcodesApi.md#postcodespostcodecountrycodeget) | **GET** /postcodes/{postcode},{countryCode} | A nowcast for a postcode.

## Documentation For Models

 - [BoundingPoints](docs/Model/BoundingPoints.md)
 - [BoundingPointsInner](docs/Model/BoundingPointsInner.md)
 - [CldCvr](docs/Model/CldCvr.md)
 - [CountryCode](docs/Model/CountryCode.md)
 - [CountryName](docs/Model/CountryName.md)
 - [DewPt](docs/Model/DewPt.md)
 - [Distance](docs/Model/Distance.md)
 - [DistancePop](docs/Model/DistancePop.md)
 - [DmaId](docs/Model/DmaId.md)
 - [DmaName](docs/Model/DmaName.md)
 - [DmaObj](docs/Model/DmaObj.md)
 - [ErrorObj](docs/Model/ErrorObj.md)
 - [FeelsLike](docs/Model/FeelsLike.md)
 - [FieldListObj](docs/Model/FieldListObj.md)
 - [Fields](docs/Model/Fields.md)
 - [Grid](docs/Model/Grid.md)
 - [HeatIndex](docs/Model/HeatIndex.md)
 - [Latitude](docs/Model/Latitude.md)
 - [Longitude](docs/Model/Longitude.md)
 - [MslPres](docs/Model/MslPres.md)
 - [NowcastArr](docs/Model/NowcastArr.md)
 - [NowcastDmaObj](docs/Model/NowcastDmaObj.md)
 - [NowcastObj](docs/Model/NowcastObj.md)
 - [NowcastOnpointObj](docs/Model/NowcastOnpointObj.md)
 - [NowcastPointObj](docs/Model/NowcastPointObj.md)
 - [NowcastPostcodeObj](docs/Model/NowcastPostcodeObj.md)
 - [OnpointId](docs/Model/OnpointId.md)
 - [OnpointObj](docs/Model/OnpointObj.md)
 - [PointObj](docs/Model/PointObj.md)
 - [Population](docs/Model/Population.md)
 - [Postcode](docs/Model/Postcode.md)
 - [PostcodeObj](docs/Model/PostcodeObj.md)
 - [PrecipFlag](docs/Model/PrecipFlag.md)
 - [PrecipIntensity](docs/Model/PrecipIntensity.md)
 - [PresTend](docs/Model/PresTend.md)
 - [RadSolar](docs/Model/RadSolar.md)
 - [RelHum](docs/Model/RelHum.md)
 - [SamplePoints](docs/Model/SamplePoints.md)
 - [SamplePointsInner](docs/Model/SamplePointsInner.md)
 - [SfcPres](docs/Model/SfcPres.md)
 - [SnowfallFlag](docs/Model/SnowfallFlag.md)
 - [SnowfallIntensity](docs/Model/SnowfallIntensity.md)
 - [SpcHum](docs/Model/SpcHum.md)
 - [SubdivCode](docs/Model/SubdivCode.md)
 - [SubdivName](docs/Model/SubdivName.md)
 - [Temp](docs/Model/Temp.md)
 - [Timestamp](docs/Model/Timestamp.md)
 - [Timezone](docs/Model/Timezone.md)
 - [WetBulb](docs/Model/WetBulb.md)
 - [WindChill](docs/Model/WindChill.md)
 - [WindDir](docs/Model/WindDir.md)
 - [WindDir100m](docs/Model/WindDir100m.md)
 - [WindDir80m](docs/Model/WindDir80m.md)
 - [WindSpd](docs/Model/WindSpd.md)
 - [WindSpd100m](docs/Model/WindSpd100m.md)
 - [WindSpd80m](docs/Model/WindSpd80m.md)

## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

support@weathersource.com

